<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
$mod_strings = Array(
'LBL_IMPORT_MODULE_NO_DIRECTORY'=>'Das Verzeichnis ',
'LBL_IMPORT_MODULE_NO_DIRECTORY_END'=>' existiert nicht oder ist schreibgeschützt',
'LBL_IMPORT_MODULE_ERROR_NO_UPLOAD'=>'Datei konnte nicht erfolgreich geladen werden, bitte nochmals versuchen',
'LBL_IMPORT_MODULE_ERROR_LARGE_FILE'=>'Datei ist zu gross. Max:',
'LBL_IMPORT_MODULE_ERROR_LARGE_FILE_END'=>'Bytes.',
'LBL_MODULE_NAME'=>'Importiere',
'LBL_TRY_AGAIN'=>'Nochmals versuchen',
'LBL_ERROR'=>'Fehler:',
'ERR_MULTIPLE'=>'Mehreren Zeilen wurden die gleichen Feldnamen zugewiesen.',
'ERR_MISSING_REQUIRED_FIELDS'=>'Es fehlen benötigte Felder:',
'ERR_SELECT_FULL_NAME'=>'Sie können das Feld -voller Name- nicht wählen, wenn Vorname und Nachname gewählt sind.',
'ERR_SELECT_FILE'=>'Datei für Upload wählen.',
'LBL_SELECT_FILE'=>'Datei wählen:',
'LBL_CUSTOM'=>'Benutzerdefiniert',
'LBL_DONT_MAP'=>'-- dieses Feld nicht importieren --',
'LBL_STEP_1_TITLE'=>'Schritt 1: Quelle wählen',
'LBL_WHAT_IS'=>'Woher stammen die Daten?',
'LBL_MICROSOFT_OUTLOOK'=>'Microsoft Outlook',
'LBL_ACT'=>'Act!',
'LBL_SALESFORCE'=>'Salesforce.com',
'LBL_MY_SAVED'=>'Meine gespeicherten Quellen:',
'LBL_PUBLISH'=>'freigeben',
'LBL_DELETE'=>'löschen',
'LBL_PUBLISHED_SOURCES'=>'freigegebene Quellen:',
'LBL_UNPUBLISH'=>'Freigabe aufheben',
'LBL_NEXT'=>'Weiter >',
'LBL_BACK'=>'< Zurück',
'LBL_STEP_2_TITLE'=>'Schritt 2: Upload Export Datei',
'LBL_HAS_HEADER'=>'hat Überschrift',

'LBL_NUM_1'=>'1.',
'LBL_NUM_2'=>'2.',
'LBL_NUM_3'=>'3.',
'LBL_NUM_4'=>'4.',
'LBL_NUM_5'=>'5.',
'LBL_NUM_6'=>'6.',
'LBL_NUM_7'=>'7.',
'LBL_NUM_8'=>'8.',
'LBL_NUM_9'=>'9.',
'LBL_NUM_10'=>'10.',
'LBL_NUM_11'=>'11.',
'LBL_NUM_12'=>'12.',
'LBL_NOW_CHOOSE'=>'Datei für Import wählen:',
'LBL_IMPORT_OUTLOOK_TITLE'=>'Microsoft Outlook kann die Daten ein in einem <b>Komma getrennte Werte /b> Format speichern, welches für den Import in das System benutzt werden kann. Um die Daten aus Outlook zu exportieren gehen Sie wie folgt vor:',
'LBL_OUTLOOK_NUM_1'=>'Starten Sie <b>Outlook</b>',
'LBL_OUTLOOK_NUM_2'=>'Wählen Sie das <b>Datei</b> Menü, dann die <b>Import/Export ...</b> Menüoption',
'LBL_OUTLOOK_NUM_3'=>'Wählen Sie <b>Export in eine Datei</b> und klicken Sie auf Weiter',
'LBL_OUTLOOK_NUM_4'=>'Wählen Sie <b>Kommagetrennte Werte (Windows)</b> und klicken Sie auf <b>Weiter</b>.<br>  Bemerkung: Eventuell werden Sie zum Installieren der Exportkomponente aufgefordert.',
'LBL_OUTLOOK_NUM_5'=>'Wählen Sie den <b>Kontakte</b> Ordner und klicken Sie auf <b>Weiter</b>. Sie können hier verschiedene Kontakteordner angeben, wenn Sie Ihre Daten in mehreren Ordnern gespeichert haben.',
'LBL_OUTLOOK_NUM_6'=>'Wählen Sie den Dateinamen und klicken Sie auf <b>Weiter</b>',
'LBL_OUTLOOK_NUM_7'=>'Klicken Sie <b>Fertig stellen</b>',
'LBL_IMPORT_ACT_TITLE'=>'Act! kann die Daten in einem <b>Komma getrennte Werte /b> Format speichern, welches für den Import in das System benutzt werden kann. Um die Daten aus ACT! zu exportieren gehen Sie wie folgt vor:',
'LBL_ACT_NUM_1'=>'Starten Sie <b>ACT!</b>',
'LBL_ACT_NUM_2'=>'Wählen Sie das <b>Datei</b> Menü, dann die <b>Datenaustausch</b> Menüoption, dann die <b>Export...</b> Menüoption',
'LBL_ACT_NUM_3'=>'Wählen Sie für den Dateityp <b>Text mit Trennzeichen </b>',
'LBL_ACT_NUM_4'=>'Geben Sie einen Dateinamen ein und wählen Sie einen Speicherort für die Exportdatei und klicken Sie <b>Weiter</b>',
'LBL_ACT_NUM_5'=>'Wählen Sie <b>nur Kontakteinträge</b>',
'LBL_ACT_NUM_6'=>'Klicken Sie <b>Optionen...</b>',
'LBL_ACT_NUM_7'=>'Wählen Sie <b>Komma</b> als Texttrennzeichen',
'LBL_ACT_NUM_8'=>'Selektieren Sie <b>Ja, Feldnamen exportieren</b> und klicken Sie <b>OK</b>',
'LBL_ACT_NUM_9'=>'Klicken Sie <b>Weiter</b>',
'LBL_ACT_NUM_10'=>'Wählen Sie <b>Alle Einträge</b> und dann <b>Fertigstellen</b>',

'LBL_IMPORT_SF_TITLE'=>'Salesforce.com kann die Daten in einem <b>Komma getrennte Werte </b> Format speichern, welches für den Import in das System benutzt werden kann. Um die Daten aus salesforce.com zu exportieren gehen Sie wie folgt vor:',
'LBL_SF_NUM_1'=>'Starten Sie Ihren Browser, gehen Sie auf http://www.salesforce.com, und melden Sie sich an',
'LBL_SF_NUM_2'=>'Klicken Sie auf Reports <b>Reports</b> im Hauptment',
'LBL_SF_NUM_3'=>'Um Organisationen zu exportieren:</b> Klicken Sie auf den <b>Aktive Organisationen</b> Link<br><b>Um Kontakte zu exportieren:</b> Klicken Sie auf den <b>Mailing Liste</b> Link',
'LBL_SF_NUM_4'=>'Bei <b>Schritt 1: Wählen Sie Ihren Report</b>, wählen Sie <b>Tabellarischer Report</b> und klicken <b>Weiter</b>',
'LBL_SF_NUM_5'=>'Bei <b>Schritt 2: Wählen Sie die Reportspalten</b>, wählen Sie die Spalten, welche Sie exportieren möchten und klicken Sie auf <b>weiter</b>',
'LBL_SF_NUM_6'=>'Bei <b>Schritt 3: Selektieren Sie die benötigten Informationen </b>, klicken Sie <b>Next</b>',
'LBL_SF_NUM_7'=>'Bei <b>Schritt 4: Ordnen der Reportspalten</b>, klicken Sie auf <b>Weiter</b>',
'LBL_SF_NUM_8'=>'Bei <b>Schritt 5: Reportkriterien:</b>, unter <b>Start Date</b>, wählen Sie ein Datum weit genug zurück, damit alle Datensätze exportiert werden. Wählen Sie danach, click <b>Run Report</b>',
'LBL_SF_NUM_9'=>'Ein Report wird erzeugt und die Seite sollte angezeigt werden <b>Report Erzeugen, Status: Vollständig.</b> Klicken Sie jetzt <b>Export zu Excel</b>',
'LBL_SF_NUM_10'=>'Bei <b>Export Report:</b>, für <b>Export Datei Format:</b>, wählen Sie  <b>durch Komma getrennte Werte .csv</b>. Klicken Sie <b>Export</b>.',
'LBL_SF_NUM_11'=>'Ein Auswahlfenster für den Speicherort der Exportdatei erscheint.',
'LBL_IMPORT_CUSTOM_TITLE'=>'Viele Applikationen erlauben den Datenexport in ein <b>Komma getrennte Textdatei (.csv)</b>. Die meisten Applikationen erfordern folgende Schritte:',
'LBL_CUSTOM_NUM_1'=>'Starten Sie die Applikation und öffen Sie die Datendatei',
'LBL_CUSTOM_NUM_2'=>'Wählen sie die <b>Speichern unter...</b> oder <b>Export...</b> Menüoption',
'LBL_CUSTOM_NUM_3'=>'Speicher Sie die Daten in einem <b>CSV</b> oder <b>durch Komma getrennte Werte</b> Format',

'LBL_STEP_3_TITLE'=>'Schritt 3: Feldzuordnung',
'LBL_STEP_1'=>'Schritt 1 von 3 : ',
'LBL_STEP_1_TITLE'=>'Bitte die .CSV Datei auswählen',
'LBL_STEP_1_TEXT'=> ' Das CRM unterstützt den Import von .csv (<b> Comma Seperated Values</b> ) Dateien. Für den Import durchsuchen Sie Ihren Computer nach der .csv Datei. Danach klicken Sie auf Weiter.',

'LBL_SELECT_FIELDS_TO_MAP'=>'Ordnen Sie die Importfelder den Feldern im CRM zu. Wenn Sie fertig sind, wählen Sie <b>Jetzt Importieren</b>:',

'LBL_DATABASE_FIELD'=>'Datenbankfeld',
'LBL_HEADER_ROW'=>'Überschrift',
'LBL_ROW'=>'Datensatz',
'LBL_SAVE_AS_CUSTOM'=>'Speichere Zuordnung:',
'LBL_CONTACTS_NOTE_1'=>'Entwerder der Nachname oder der Fullname muss zugeordnet werden.',
'LBL_CONTACTS_NOTE_2'=>'Wenn der Fullname zugeordnet wird, werden Vor- und Nachname ignoriert.',
'LBL_CONTACTS_NOTE_3'=>'Wenn der Fullname zugeordnet wird, werden dieser aufgeteilt in Vorname und Nachname.',
'LBL_CONTACTS_NOTE_4'=>'Die Felder Adress Street 2 und Adress Street 3 werden beim Import zusammengesetzt zur Hauptadresse.',
'LBL_ACCOUNTS_NOTE_1'=>'Organisationsname muss zugeordnet werden.',
'LBL_ACCOUNTS_NOTE_2'=>'Die Felder Adress Street 2 und Adress Street 3 werden beim Import zusammengesetzt zur Hauptadresse.',
'LBL_POTENTIALS_NOTE_1'=>'Verkaufspotential, Organisation, Abschlussdatum, und Verkaufsstufe sind Pflichtfelder.',
'LBL_OPPORTUNITIES_NOTE_1'=>'Gelegenheit, Organisation, Abschlussdatum, und Verkaufsstufe sind Pflichtfelder.',
'LBL_LEADS_NOTE_1'=>'Nachname muss zugewiesen werden.',
'LBL_LEADS_NOTE_2'=>'Organsiation muss zugewiesen werden.',
'LBL_IMPORT_NOW'=>'Jetzt Importieren',
'LBL_'=>'',
'LBL_CANNOT_OPEN'=>'Kann die Importdatei nicht öffnen',
'LBL_NOT_SAME_NUMBER'=>'Unterschiedliche Anzahl Felder pro Datensatz gefunden',
'LBL_NO_LINES'=>'Es sind keine Daten in der Importdatei',
'LBL_FILE_ALREADY_BEEN_OR'=>'Die Importdatei wurde bereits verarbeitet oder existiert nicht',
'LBL_SUCCESS'=>'Erfolgreich:',
'LBL_SUCCESSFULLY'=>'Erfolgreich importiert',
'LBL_LAST_IMPORT_UNDONE'=>'Ihr letzter Import wurde rückgängig gemacht',
'LBL_NO_IMPORT_TO_UNDO'=>'Es gibt keinen Import, welcher rückgängig gemacht werden kann.',
'LBL_FAIL'=>'Fehler:',
'LBL_RECORDS_SKIPPED'=>'Datensätze wurden übergangen, weil ein oder mehrere Pflichtfelder nicht vorhanden waren',
'LBL_IDS_EXISTED_OR_LONGER'=>'Datensätze wurden übergangen, weil die id\'s bereits existierten oder deren Länge 36 Zeichen überschritten hat',
'LBL_RESULTS'=>'Resultat',
'LBL_IMPORT_MORE'=>'Importiere weitere',
'LBL_FINISHED'=>'Fertig',
'LBL_UNDO_LAST_IMPORT'=>'Letzten Import rückgängig machen',

'LBL_SUCCESS_1' => 'Anzahl der Datensätze, die erfolgreich importiert / akualisiert wurden : ',
'LBL_SKIPPED_1' => 'Anzahl der Datensätze, die nicht importiert wurden, da Feldangaben fehlten : ',

//Added for patch2 - Products Import Notes
'LBL_PRODUCTS_NOTE_1'=>'Ein Bezug zum Produktnamen muss hergestellt sein',
'LBL_PRODUCTS_NOTE_2'=>'Bitte prüfen Sie vor dem Import ob eine Spalte doppelt vorhanden ist.',

//Added for version 5
'LBL_FILE_LOCATION'=>'Dateispeicherstelle :',
'LBL_STEP_2_3'=>'Schritt 2 von 3 :',
'LBL_LIST_MAPPING'=>'Anzeige & Feldzuordnung',
'LBL_STEP_2_MSG'=>'Die folgenden Tabellen zeigen das Importergebnis ',
'LBL_STEP_2_MSG1'=>'und andere Details.',
'LBL_STEP_2_TXT'=>'Ordnen Sie die Importfelder den Feldern im CRM zu. Dieser Bezug orientiert an Ihren Stammdaten für ',
'LBL_USE_SAVED_MAPPING'=>'Nutze vorhandene Feldzuordnung:',
'LBL_MAPPING'=>'Feldzuordnung',
'LBL_HEADERS'=>'Überschrift :',
'LBL_ERROR_MULTIPLE'=>'Wahrscheinlich haben Sie gleiche CRM Felder doppelt verbunden. Bitte überprüfen Sie Ihre Zuordnung.',
'LBL_STEP_3_3'=>'Schritt 3 von 3 : ',
'LBL_MAPPING_RESULTS'=>'Mapping Ergebnisse ',
'LBL_LAST_IMPORTED'=>'Zuletzt Importiert',
//Added for sript alerts
'PLEASE_CHECK_MAPPING' => "' wurde mehr als einmal referenziert.",
'MAP_MANDATORY_FIELD' => 'Die Pflichfelder sind mit zu erfassen. "',
'ENTER_SAVEMAP_NAME' => 'Bitte geben Sie der Vorlage einen Namen.',

//Added for 5.0.3
'to'=>'zu',
'of'=>'von',
'are_imported_succesfully'=>'wurden erfolgreich importiert',

// Added after 5.0.4 GA

//added for duplicate handling 
'LBL_LAST_IMPORT'=>'zuletzt importiert',
'Select_Criteria_For_Duplicate' => 'Wählen Sie Kriterien für den Dublettencheck',
'Manual_Merging' => 'manuell zusammenführen',
'Auto_Merging' => 'automatisch zusammenführen',
'Ignore_Duplicate' => 'ignoriere Duplikate beim Import',
'Overwrite_Duplicate' => 'überschreibe die Duplikate im CRM',
'Duplicate_Records_Skipped_Info' => 'Anzahl der Datensätze die nicht übernommen wurden, da diese als Duplikate identifizeirt wurden: ',
'Duplicate_Records_Overwrite_Info' => 'Anzahl der Datensätze, die überschrieben worden sind, da diese als Duplikate erkannt wurden: ',
'LBL_STEP_4_4' => 'Schritt 4 von 4 : ',
'LBL_STEP_3_4'=>'Schritt 3 von 4 :',
'LBL_STEP_2_4'=>'Schritt 2 von 4 :',
'LBL_STEP_1_4'=>'Schritt 1 von 4 : ',

'LBL_DELIMITER' => 'Trennzeichen:',
'LBL_FORMAT' => 'Format:',

'LBL_MAX_FILE_SIZE' => ' ist die maximale Dateigröße',

'LBL_MERGE_FIELDS_DUPLICATE' => 'Zusammenführung von importierten Duplikaten',
'Customer Portal Login Details' => 'Kundenportal Login Informationen',
);

$mod_list_strings = Array(
'contacts_import_fields' => Array(
	"firstname"=>"Vorname"
	,"lastname"=>"Nachname"
	,"salutationtype"=>"Anrede"
	,"leadsource"=>"Lead Quelle"
	,"birthday"=>"Geburtstag"
	,"donotcall"=>"Nicht Anrufen"
	,"emailoptout"=>"E-Mail Opt Aus"
	,"account_id"=>"Organisationsname"
	,"title"=>"Funktion"
	,"department"=>"Abteilung"
	,"homephone"=>"Telefon (Privat)"
	,"mobile"=>"Telefon (Mobil)"
	,"phone"=>"Telefon (Arbeit)"
	,"otherphone"=>"Telefon (Weitere)"
	,"fax"=>"Fax"
	,"email"=>"E-Mail"
	,"otheremail"=>"E-Mail (andere)"
	,"yahooid"=>"Yahoo E-Mail"
	,"assistant"=>"Assistent"
	,"assistantphone"=>"Assistent Telefon"
	,"mailingstreet"=>"Postadresse Straße"
	,"mailingpobox"=>"Postadresse Postfach"
	,"mailingcity"=>"Postadresse Ort"
	,"mailingstate"=>"Postadresse Bundesland"
	,"mailingzip"=>"Postadresse PLZ"
	,"mailingcountry"=>"Postadresse Land"
	,"otherstreet"=>"Weitere Addresse Straße"
	,"otherpobox"=>"Weitere Addresse Postfach"
	,"othercity"=>"Weitere Addresse Ort"
	,"otherstate"=>"Weitere Addresse Bundesland"
	,"otherzip"=>"Weitere Addresse PLZ"
	,"othercountry"=>"Weitere Addresse Land"
	,"description"=>"Beschreibung"
	,"assigned_user_id"=>"Zuständig"
	,"secondaryemail"=>"Zweite E-Mail-Adresse"
	),

'accounts_import_fields' => Array(
	"accountname"=>"Organisationsname",
	"website"=>"Webseite",
	"industry"=>"Branche",
	"accounttype"=>"Typ",
	"tickersymbol"=>"Org. Namenszusatz",
	"parent_name"=>"Mitglied von",
	"employees"=>"Mitarbeiter",
	"ownership"=>"Besitzer",
	"phone"=>"Telefon",
	"fax"=>"Fax",
	"otherphone"=>"Weiteres Telefon",
	"email1"=>"E-Mail",
	"email2"=>"Weitere E-Mail",
	"rating"=>"Bewertung",
	"siccode"=>"Börsencode",
	"annual_revenue"=>"Jahresumsatz",
	"bill_street"=>"Rechnungsadresse Straße",
	"bill_pobox"=>"Rechnungsadresse Postfach",
	"bill_city"=>"Rechnungsadresse Ort",
	"bill_state"=>"Rechnungsadresse Bundesland",
	"bill_code"=>"Rechnungsadresse PLZ",
	"bill_country"=>"Rechnungsadresse Land",
	"ship_street"=>"Lieferadresse Straße",
	"ship_pobox"=>"Lieferadresse Postfach",
	"ship_city"=>"Lieferadresse Ort",
	"ship_state"=>"Lieferadresse Bundesland",
	"ship_code"=>"Lieferadresse PLZ",
	"ship_country"=>"Lieferadresse Land",
	"description"=>"Beschreibung",
	"assigned_user_id"=>"zuständig"
	),

'potentials_import_fields' => Array(
                 "potentialname"=>"Potentialname"
                , "account_id"=>"Organisationsname"
                , "opportunity_type"=>"Potentialtyp"
                , "leadsource"=>"Lead Quelle"
                , "amount"=>"Betrag"
                , "closingdate"=>"Abschlussdatum"
                , "nextstep"=>"nächster Schritt"
                , "sales_stage"=>"Verkaufsstufe"
                , "probability"=>"Wahrscheinlichkeit"
                , "description"=>"Beschreibung"
                ,"assigned_user_id"=>"zuständig"
                ),

'leads_import_fields' => Array(
		"salutationtype"=>"Anrede",
		"firstname"=>"Vorname",
		"phone"=>"Telefon",
		"lastname"=>"Nachname",
		"mobile"=>"Mobil",
		"company"=>"Organisation",
		"fax"=>"Fax",
		"designation"=>"Funktion",
		"email"=>"E-Mail",
		"leadsource"=>"Lead Quelle",
		"website"=>"Webseite",
		"industry"=>"Branche",
		"leadstatus"=>"Lead Status",
		"annualrevenue"=>"Jahresumsatz",
		"rating"=>"Bewertung",
		"noofemployees"=>"Anzahl Mitarbeiter",
		"assigned_user_id"=>"Zuständig",
		"yahooid"=>"Yahoo E-Mail",
		"lane"=>"Straße",
		"pobox"=>"Postfach",
		"code"=>"PLZ",
		"city"=>"Ort",
		"country"=>"Land",
		"state"=>"Bundesland",
		"description"=>"Beschreibung",
		"assigned_user_id"=>"zuständig",
		"secondaryemail"=>"Zweite E-Mail-Adresse"
    ),

 'products_import_fields' => Array(
 	'productname'=>'Produktname',
 	'productcode'=>'Produktcode',
 	'productcategory'=>'Produktkategorie',
 	'manufacturer'=>'Hersteller',
 	'product_description'=>'Produktbeschreibung',
 	'qty_per_unit'=>'Menge Per/Einheit',
 	'unit_price'=>'Einheitenpreis',
 	'weight'=>'Gewicht',
 	'pack_size'=>'Packungsgrösse',
 	'start_date'=>'Anfangsdatum',
 	'expiry_date'=>'Ablaufdatum ',
 	'cost_factor'=>'Kostenfaktor',
 	'commissionmethod'=>'Kommissionsmethode',
 	'discontinued'=>'Eingestellt',
 	'commissionrate'=>'Kommissionsrate',
	'sales_start_date'=>'Verkaufsstart-Datum',
	'sales_end_date'=>'Verkaufsende-Datum',
	'usageunit'=>'Handelseinheit',
	'serialno'=>'Seriennummer',
	'currency'=>'Währung',
	'reorderlevel'=>'Wiederbestellniveau',
	'website'=>'Web-Seite',
	'taxclass'=>'Steuerklasse',
	'mfr_part_no'=>'Hersteller Teilenummer',
	'vendor_part_no'=>'Lieferant Teilenummer',
	'qtyinstock'=>'Menge im Lager',
	'productsheet'=>'Produktdatenblatt',
	'qtyindemand'=>'Menge angefordert',
	'glacct'=>'FIBU Konto',
	'assigned_user_id'=>'zuständig'
	 ),
//Pavani...adding list of import fields for helpdesk and vendors
'helpdesk_import_fields' => Array(
        "ticketid"=>"Ticketnr.",
        "priority"=>"Priorität",
        "severity"=>"Severity",
        "status"=>"Status",
        "category"=>"Kategorie",
        "title"=>"Titel",
        "description"=>"Beschreibung",
        "solution"=>"Lösung"
        ),

'vendors_import_fields' => Array(
        "vendorid"=>"Lieferantennr.",
        "vendorname"=>"Lieferantenname",
        "phone"=>"Telefon",
        "email"=>"E-Mail",
        "website"=>"Webseite",
        "category"=>"Kategorie",
        "street"=>"Straße",
        "city"=>"Ort",
        "state"=>"Bundesland",
        "pobox"=>"Postfach",
        "postalcode"=>"PLZ",
        "country"=>"Land",
        "description"=>"Beschreibung"
        )
//Pavani...end list
);

?>